# refgenconf

[![Build Status](https://travis-ci.org/databio/refgenconf.svg?branch=master)](https://travis-ci.org/databio/refgenconf)
[![Coverage Status](https://coveralls.io/repos/github/vreuter/refgenconf/badge.svg?branch=master)](https://coveralls.io/github/vreuter/refgenconf?branch=master)

Configuration object for refgenie *et al.*

Documentation for `refgenconf` can be found with the primary documentation for `refgenie`.
